Class: Array
- Inherits:
-
Object
- Object
- Array
- Defined in:
- lib/rails_dictionary/array_core_ext.rb
Instance Method Summary collapse
-
#extract_to_hash(keys_array) ⇒ Object
Deprecated: the Array monkey-patch will be removed in a future major release.
Instance Method Details
#extract_to_hash(keys_array) ⇒ Object
Deprecated: the Array monkey-patch will be removed in a future major release. The real logic now lives in RailsDictionary.extract_to_hash.
4 5 6 7 8 9 |
# File 'lib/rails_dictionary/array_core_ext.rb', line 4 def extract_to_hash(keys_array) RailsDictionary.deprecator.warn( "Array#extract_to_hash is deprecated; use RailsDictionary.extract_to_hash instead." ) RailsDictionary.extract_to_hash(self, keys_array) end |